@@ -26,6 +26,7 @@ modules = [
     "behance",
     "blogger",
     "bunkr",
+    "catbox",
     "comicvine",
     "cyberdrop",
     "danbooru",
@@ -150,6 +151,7 @@ modules = [
     "wikieat",
     "xhamster",
     "xvideos",
+    "zerochan",
     "booru",
     "moebooru",
     "foolfuuka",
