@@ -270,6 +270,7 @@ class InstagramExtractor(Extractor):
                 "post_shortcode": post["code"],
                 "likes": post["like_count"],
                 "pinned": post.get("timeline_pinned_user_ids", ()),
+                "date": text.parse_timestamp(post.get("taken_at")),
             }
 
             caption = post["caption"]
@@ -399,6 +400,8 @@ class InstagramExtractor(Extractor):
             self.log.debug("Cursor: %s", self._cursor)
 
     def _pagination_api(self, endpoint, params=None):
+        if params is None:
+            params = {}
         while True:
             data = self._request_api(endpoint, params=params)
             yield from data["items"]
@@ -509,7 +512,7 @@ class InstagramChannelExtractor(InstagramExtractor):
 class InstagramSavedExtractor(InstagramExtractor):
     """Extractor for ProfilePage saved media"""
     subcategory = "saved"
-    pattern = USER_PATTERN + r"/saved"
+    pattern = USER_PATTERN + r"/saved/?$"
     test = ("https://www.instagram.com/instagram/saved/",)
 
     def posts(self):
@@ -518,6 +521,30 @@ class InstagramSavedExtractor(InstagramExtractor):
         return self._pagination_graphql(query_hash, variables)
 
 
+class InstagramCollectionExtractor(InstagramExtractor):
+    """Extractor for ProfilePage saved collection media"""
+    subcategory = "collection"
+    pattern = USER_PATTERN + r"/saved/([^/?#]+)/([^/?#]+)"
+    test = (
+        "https://www.instagram.com/instagram/saved/collection_name/123456789/",
+    )
+
+    def __init__(self, match):
+        InstagramExtractor.__init__(self, match)
+        self.user, self.collection_name, self.collection_id = match.groups()
+
+    def metadata(self):
+        return {
+            "collection_id"  : self.collection_id,
+            "collection_name": text.unescape(self.collection_name),
+        }
+
+    def posts(self):
+        endpoint = "/v1/feed/collection/{}/posts/".format(self.collection_id)
+        for item in self._pagination_api(endpoint):
+            yield item["media"]
+
+
 class InstagramTagExtractor(InstagramExtractor):
     """Extractor for TagPage"""
     subcategory = "tag"
